@@ -1,7 +1,7 @@
 zelig2gamma <- function(formula, model, data, M, ...) {
   mf <-  match.call(expand.dots = TRUE)
-  mf$model <- mf$M <- NULL
-  mf[[1]] <- as.name("glm")
-  mf$family <- as.name("Gamma")
+  mf$model <- mf$M <- mf$robust <- NULL
+  mf[[1]] <- glm
+  mf$family <- Gamma
   as.call(mf)
 }
